/* GrandPerspective, Version 3.4.2 
 *   A utility for Mac OS X that graphically shows disk usage. 
 * Copyright (C) 2005-2022, Erwin Bonsma 
 * 
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the Free 
 * Software Foundation; either version 2 of the License, or (at your option) 
 * any later version. 
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
 * more details. 
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. 
 */

#import "DirectoryViewControlSettings.h"

#import "DirectoryViewDisplaySettings.h"
#import "PreferencesPanelControl.h"
#import "TreeDrawerBaseSettings.h"

@implementation DirectoryViewControlSettings

- (instancetype) init {
  NSUserDefaults  *ud = NSUserDefaults.standardUserDefaults;

  return [self initWithDisplaySettings: [DirectoryViewDisplaySettings defaultSettings]
                      unzoomedViewSize: NSMakeSize([ud floatForKey: DefaultViewWindowWidth],
                                                   [ud floatForKey: DefaultViewWindowHeight])
                          displayDepth: TreeDrawerBaseSettings.defaultDisplayDepth];
}

- (instancetype) initWithDisplaySettings:(DirectoryViewDisplaySettings *)displaySettings
                        unzoomedViewSize:(NSSize)unzoomedViewSize
                            displayDepth:(unsigned)displayDepth {
  if (self = [super init]) {
    _displaySettings = [displaySettings retain];
    _unzoomedViewSize = unzoomedViewSize;
    _displayDepth = displayDepth;
  }
  
  return self;
}

- (void) dealloc {
  [_displaySettings release];

  [super dealloc];
}

@end
